Crate kcr_hnc_x_k8s_io

Crate kcr_hnc_x_k8s_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the hnc.x-k8s.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

hnc.x-k8s.io/v1alpha2

  • HierarchicalResourceQuota
  • HierarchyConfiguration
  • HNCConfiguration
  • SubnamespaceAnchor

Modules

v1alpha2